–progress=PROGRESS — Translate Toolkit 2.0.0rc1 documentation

# –progress=PROGRESS

All of the programs can give visual feedback. This options allows you to select the style of that feedback.

In the examples we are converting and OpenOffice.org 2.0 sdf/gsi file into POT files using oo2po.

## none

No visual feedback, this is useful if you want to use any of the scripts as part of another script and don’t want feedback to interfere with the operation.

    $ oo2po -P --progress=none en-US.sdf pot
    $

## dots

Use visual dots to represent progress. Each dot represent a file that has been processed.

    $ oo2po -P --progress=dots en-US.sdf pot
    .............................................................................................
    .............................................................................................
    .........................................
    $

## bar (default)

Use a progress bar consisting of hashes (#) to show progress.

    $ oo2po -P --progress=bar en-US.sdf pot
    processing 227 files...
    [##############################             ]  69%

This is the default mode of operation, therefore this command would create the same output.

    $ oo2po -P en-US.sdf pot

## verbose

Combine the hash (#) progress bar form the bar option with the actual names of files that have been processed.

    $ oo2po -P --progress=verbose en-US.sdf pot
    processing 227 files...
    so3/src.oo
    dbaccess/source/ui/uno.oo
    helpcontent2/source/text/shared.oo
    wizards/source/formwizard.oo
    sch/source/ui/dlg.oo
    helpcontent2/source/text/sbasic/shared/01.oo
    dbaccess/source/core/resource.oo
    svtools/source/sbx.oo
    dbaccess/source/ui/relationdesign.oo
    scp2/source/writer.oo
    filter/source/xsltdialog.oo
    [##                                         ]   5%

## names

Prints out only the filenames without any other progress indicator. This is a good option when outputting to a log file rather than a terminal.

    $ oo2po -P --progress=names en-US.sdf pot
    so3/src.oo
    dbaccess/source/ui/uno.oo
    helpcontent2/source/text/shared.oo
    wizards/source/formwizard.oo
    sch/source/ui/dlg.oo
    helpcontent2/source/text/sbasic/shared/01.oo
    dbaccess/source/core/resource.oo
    svtools/source/sbx.oo
    dbaccess/source/ui/relationdesign.oo
    scp2/source/writer.oo
    filter/source/xsltdialog.oo